@@ -1,4 +1,4 @@
-__version__ = '0.2.1'
+__version__ = '0.2.2'
 
 import sys, os
 from time import sleep
@@ -21,7 +21,7 @@ def slow_print(*strings, time = 0.045, sep = ' ', end = '\n', file = sys.stdout)
         file.flush()
         sleep(time)
     num -= 1
-    if num != 0 and strings[len(strings)-num-1].startswith("\033") == False:
+    if num != 0 or strings[len(strings)-num-1].startswith("\033") == False:
       file.write(sep)
       file.flush()	
   file.flush()
@@ -32,4 +32,10 @@ def wait(time = 1):
 def rgb(r, g, b):
 		return "\033[38;2;{};{};{}m".format(r, g, b)
 def rgb_reset():
-	return "\033[38;2;255;255;255m"
\ No newline at end of file
+	return "\033[38;2;255;255;255m"
+def bold():
+  return "\033[1m" 
+def italics():
+  return "\033[3m" 
+def underline():
+  return "\033[4m" 
\ No newline at end of file
